@@ -46,6 +46,11 @@ assert(
   format_sci(1000000L) == '1000000'
 )
 
+# https://github.com/yihui/knitr/issues/1625
+assert('format_sci() does not convert roman numerals to arabic numerals', {
+  format_sci(as.roman(c(1, 4, 7, 33, 100))) %==% c('I', 'IV', 'VII', 'XXXIII', 'C')
+})
+
 assert(
   'format_sci() for Rnw does not add \\ensuremath{} at all',
   !grepl('[\\]ensuremath', format_sci(c(1e4, 1.2345e10, 2 * pnorm(-(3:4)), -Inf)))
@@ -141,6 +146,15 @@ assert(
   combine_words(c('a', 'b', 'c'), before = '``', after = "''") %==% "``a'', ``b'', and ``c''"
 )
 
+assert('split_lines() splits a character vector into lines by \\n', {
+  (split_lines('') %==% '')
+  (split_lines(NULL) %==% NULL)
+  (split_lines('a\nb') %==% c('a', 'b'))
+  (split_lines('a\n') %==% c('a', ''))
+  (split_lines('a\nb\n\n') %==% c('a', 'b', '', ''))
+  (split_lines(c('a\nb', '', ' ', 'c')) %==% c('a', 'b', '', ' ', 'c'))
+})
+
 opts = list(fig.cap = 'Figure "caption" <>.', fig.lp = 'Fig:', label = 'foo')
 assert(
   '.img.cap() generates the figure caption and alt attribute',
@@ -163,3 +177,15 @@ assert(
   restore_raw_output(pre$value, pre$chunks) %==%
     '<em>hello</em>\n<special>content</special> *protect* me!\n<em>world</em>'
 )
+
+assert('raw_block() returns a raw attribute block for Pandoc', {
+  (raw_latex('\\emph{x}') == '\n```{=latex}\n\\emph{x}\n```\n')
+  (raw_html('<i>foo</i>') == '\n```{=html}\n<i>foo</i>\n```\n')
+})
+
+assert(
+  'block_class() turns a character vector into Pandoc attributes for code block classes',
+  block_class(NULL) %==% NULL, block_class('a') %==% '{.a}',
+  block_class('a b') %==% '{.a .b}',
+  block_class(c('a', 'b')) %==% '{.a .b}'
+)
